@@ -1,4 +1,6 @@
 # util.py
+import sys
+import time
 
 class Singleton(object):
     def __new__(cls, *args, **kwds):
@@ -17,4 +19,9 @@ class Singleton(object):
         it.init(*args, **kwds)
         return it      
     def init(self, *args, **kwds):
-        pass
\ No newline at end of file
+        pass
+    
+if sys.platform.startswith("win"):
+    get_time = time.clock
+else:
+    get_time = time.time
\ No newline at end of file
